# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import ponsim_pb2 as voltha__protos_dot_ponsim__pb2


class PonSimStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendFrame = channel.unary_unary(
                '/voltha.PonSim/SendFrame',
                request_serializer=voltha__protos_dot_ponsim__pb2.PonSimFrame.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReceiveFrames = channel.unary_stream(
                '/voltha.PonSim/ReceiveFrames',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_ponsim__pb2.PonSimFrame.FromString,
                )
        self.GetDeviceInfo = channel.unary_unary(
                '/voltha.PonSim/GetDeviceInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_ponsim__pb2.PonSimDeviceInfo.FromString,
                )
        self.UpdateFlowTable = channel.unary_unary(
                '/voltha.PonSim/UpdateFlowTable',
                request_serializer=voltha__protos_dot_ponsim__pb2.FlowTable.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetStats = channel.unary_unary(
                '/voltha.PonSim/GetStats',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_ponsim__pb2.PonSimMetrics.FromString,
                )


class PonSimServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReceiveFrames(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFlowTable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PonSimServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFrame,
                    request_deserializer=voltha__protos_dot_ponsim__pb2.PonSimFrame.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReceiveFrames': grpc.unary_stream_rpc_method_handler(
                    servicer.ReceiveFrames,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_ponsim__pb2.PonSimFrame.SerializeToString,
            ),
            'GetDeviceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeviceInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_ponsim__pb2.PonSimDeviceInfo.SerializeToString,
            ),
            'UpdateFlowTable': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFlowTable,
                    request_deserializer=voltha__protos_dot_ponsim__pb2.FlowTable.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStats,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_ponsim__pb2.PonSimMetrics.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'voltha.PonSim', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PonSim(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.PonSim/SendFrame',
            voltha__protos_dot_ponsim__pb2.PonSimFrame.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReceiveFrames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/voltha.PonSim/ReceiveFrames',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_ponsim__pb2.PonSimFrame.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeviceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.PonSim/GetDeviceInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_ponsim__pb2.PonSimDeviceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFlowTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.PonSim/UpdateFlowTable',
            voltha__protos_dot_ponsim__pb2.FlowTable.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.PonSim/GetStats',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_ponsim__pb2.PonSimMetrics.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/meta.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/meta.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\032org.opencord.voltha.commonZ.github.com/opencord/voltha-protos/v3/go/common',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18voltha_protos/meta.proto\x12\x06voltha\x1a google/protobuf/descriptor.proto\"\x18\n\tChildNode\x12\x0b\n\x03key\x18\x01 \x01(\t*2\n\x06\x41\x63\x63\x65ss\x12\n\n\x06\x43ONFIG\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\r\n\tREAL_TIME\x10\x02:G\n\nchild_node\x12\x1d.google.protobuf.FieldOptions\x18\xec\xde\xd9\x03 \x01(\x0b\x32\x11.voltha.ChildNode:@\n\x06\x61\x63\x63\x65ss\x12\x1d.google.protobuf.FieldOptions\x18\xed\xde\xd9\x03 \x01(\x0e\x32\x0e.voltha.AccessBL\n\x1aorg.opencord.voltha.commonZ.github.com/opencord/voltha-protos/v3/go/commonb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_ACCESS = _descriptor.EnumDescriptor(
  name='Access',
  full_name='voltha.Access',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONFIG', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REAL_TIME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=96,
  serialized_end=146,
)
_sym_db.RegisterEnumDescriptor(_ACCESS)

Access = enum_type_wrapper.EnumTypeWrapper(_ACCESS)
CONFIG = 0
READ_ONLY = 1
REAL_TIME = 2

CHILD_NODE_FIELD_NUMBER = 7761772
child_node = _descriptor.FieldDescriptor(
  name='child_node', full_name='voltha.child_node', index=0,
  number=7761772, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ACCESS_FIELD_NUMBER = 7761773
access = _descriptor.FieldDescriptor(
  name='access', full_name='voltha.access', index=1,
  number=7761773, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_CHILDNODE = _descriptor.Descriptor(
  name='ChildNode',
  full_name='voltha.ChildNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.ChildNode.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=94,
)

DESCRIPTOR.message_types_by_name['ChildNode'] = _CHILDNODE
DESCRIPTOR.enum_types_by_name['Access'] = _ACCESS
DESCRIPTOR.extensions_by_name['child_node'] = child_node
DESCRIPTOR.extensions_by_name['access'] = access
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChildNode = _reflection.GeneratedProtocolMessageType('ChildNode', (_message.Message,), {
  'DESCRIPTOR' : _CHILDNODE,
  '__module__' : 'voltha_protos.meta_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ChildNode)
  })
_sym_db.RegisterMessage(ChildNode)

child_node.message_type = _CHILDNODE
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(child_node)
access.enum_type = _ACCESS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(access)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/common.proto',
  package='common',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ.github.com/opencord/voltha-protos/v3/go/common',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1avoltha_protos/common.proto\x12\x06\x63ommon\"\x10\n\x02ID\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x03IDs\x12\x19\n\x05items\x18\x01 \x03(\x0b\x32\n.common.ID\"u\n\nAdminState\"g\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0ePREPROVISIONED\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03\x12\x15\n\x11\x44OWNLOADING_IMAGE\x10\x04\x12\x0b\n\x07\x44\x45LETED\x10\x05\"g\n\nOperStatus\"Y\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nDISCOVERED\x10\x01\x12\x0e\n\nACTIVATING\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\"E\n\rConnectStatus\"4\n\x05Types\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bUNREACHABLE\x10\x01\x12\r\n\tREACHABLE\x10\x02\"\xc1\x01\n\rOperationResp\x12\x37\n\x04\x63ode\x18\x01 \x01(\x0e\x32).common.OperationResp.OperationReturnCode\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\"^\n\x13OperationReturnCode\x12\x15\n\x11OPERATION_SUCCESS\x10\x00\x12\x15\n\x11OPERATION_FAILURE\x10\x01\x12\x19\n\x15OPERATION_UNSUPPORTED\x10\x02\",\n\tValueType\"\x1f\n\x04Type\x12\t\n\x05\x45MPTY\x10\x00\x12\x0c\n\x08\x44ISTANCE\x10\x01\"C\n\x0eValueSpecifier\x12\n\n\x02id\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0e\x32\x16.common.ValueType.Type\"Q\n\x0cReturnValues\x12\x0b\n\x03Set\x18\x01 \x01(\r\x12\x13\n\x0bUnsupported\x18\x02 \x01(\r\x12\r\n\x05\x45rror\x18\x03 \x01(\r\x12\x10\n\x08\x44istance\x18\x04 \x01(\r*\x1c\n\x0cTestModeKeys\x12\x0c\n\x08\x61pi_test\x10\x00\x42\x45\n\x13org.opencord.volthaZ.github.com/opencord/voltha-protos/v3/go/commonb\x06proto3'
)

_TESTMODEKEYS = _descriptor.EnumDescriptor(
  name='TestModeKeys',
  full_name='common.TestModeKeys',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='api_test', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=779,
  serialized_end=807,
)
_sym_db.RegisterEnumDescriptor(_TESTMODEKEYS)

TestModeKeys = enum_type_wrapper.EnumTypeWrapper(_TESTMODEKEYS)
api_test = 0


_ADMINSTATE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='common.AdminState.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPROVISIONED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOADING_IMAGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=104,
  serialized_end=207,
)
_sym_db.RegisterEnumDescriptor(_ADMINSTATE_TYPES)

_OPERSTATUS_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='common.OperStatus.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISCOVERED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVATING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=223,
  serialized_end=312,
)
_sym_db.RegisterEnumDescriptor(_OPERSTATUS_TYPES)

_CONNECTSTATUS_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='common.ConnectStatus.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNREACHABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REACHABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=331,
  serialized_end=383,
)
_sym_db.RegisterEnumDescriptor(_CONNECTSTATUS_TYPES)

_OPERATIONRESP_OPERATIONRETURNCODE = _descriptor.EnumDescriptor(
  name='OperationReturnCode',
  full_name='common.OperationResp.OperationReturnCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPERATION_SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_UNSUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=485,
  serialized_end=579,
)
_sym_db.RegisterEnumDescriptor(_OPERATIONRESP_OPERATIONRETURNCODE)

_VALUETYPE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='common.ValueType.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTANCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=594,
  serialized_end=625,
)
_sym_db.RegisterEnumDescriptor(_VALUETYPE_TYPE)


_ID = _descriptor.Descriptor(
  name='ID',
  full_name='common.ID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='common.ID.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=54,
)


_IDS = _descriptor.Descriptor(
  name='IDs',
  full_name='common.IDs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='common.IDs.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=88,
)


_ADMINSTATE = _descriptor.Descriptor(
  name='AdminState',
  full_name='common.AdminState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADMINSTATE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=207,
)


_OPERSTATUS = _descriptor.Descriptor(
  name='OperStatus',
  full_name='common.OperStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPERSTATUS_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=312,
)


_CONNECTSTATUS = _descriptor.Descriptor(
  name='ConnectStatus',
  full_name='common.ConnectStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTSTATUS_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=383,
)


_OPERATIONRESP = _descriptor.Descriptor(
  name='OperationResp',
  full_name='common.OperationResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='common.OperationResp.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_info', full_name='common.OperationResp.additional_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPERATIONRESP_OPERATIONRETURNCODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=579,
)


_VALUETYPE = _descriptor.Descriptor(
  name='ValueType',
  full_name='common.ValueType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VALUETYPE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=625,
)


_VALUESPECIFIER = _descriptor.Descriptor(
  name='ValueSpecifier',
  full_name='common.ValueSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='common.ValueSpecifier.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='common.ValueSpecifier.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=694,
)


_RETURNVALUES = _descriptor.Descriptor(
  name='ReturnValues',
  full_name='common.ReturnValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Set', full_name='common.ReturnValues.Set', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Unsupported', full_name='common.ReturnValues.Unsupported', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Error', full_name='common.ReturnValues.Error', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Distance', full_name='common.ReturnValues.Distance', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=696,
  serialized_end=777,
)

_IDS.fields_by_name['items'].message_type = _ID
_ADMINSTATE_TYPES.containing_type = _ADMINSTATE
_OPERSTATUS_TYPES.containing_type = _OPERSTATUS
_CONNECTSTATUS_TYPES.containing_type = _CONNECTSTATUS
_OPERATIONRESP.fields_by_name['code'].enum_type = _OPERATIONRESP_OPERATIONRETURNCODE
_OPERATIONRESP_OPERATIONRETURNCODE.containing_type = _OPERATIONRESP
_VALUETYPE_TYPE.containing_type = _VALUETYPE
_VALUESPECIFIER.fields_by_name['value'].enum_type = _VALUETYPE_TYPE
DESCRIPTOR.message_types_by_name['ID'] = _ID
DESCRIPTOR.message_types_by_name['IDs'] = _IDS
DESCRIPTOR.message_types_by_name['AdminState'] = _ADMINSTATE
DESCRIPTOR.message_types_by_name['OperStatus'] = _OPERSTATUS
DESCRIPTOR.message_types_by_name['ConnectStatus'] = _CONNECTSTATUS
DESCRIPTOR.message_types_by_name['OperationResp'] = _OPERATIONRESP
DESCRIPTOR.message_types_by_name['ValueType'] = _VALUETYPE
DESCRIPTOR.message_types_by_name['ValueSpecifier'] = _VALUESPECIFIER
DESCRIPTOR.message_types_by_name['ReturnValues'] = _RETURNVALUES
DESCRIPTOR.enum_types_by_name['TestModeKeys'] = _TESTMODEKEYS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ID = _reflection.GeneratedProtocolMessageType('ID', (_message.Message,), {
  'DESCRIPTOR' : _ID,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.ID)
  })
_sym_db.RegisterMessage(ID)

IDs = _reflection.GeneratedProtocolMessageType('IDs', (_message.Message,), {
  'DESCRIPTOR' : _IDS,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.IDs)
  })
_sym_db.RegisterMessage(IDs)

AdminState = _reflection.GeneratedProtocolMessageType('AdminState', (_message.Message,), {
  'DESCRIPTOR' : _ADMINSTATE,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.AdminState)
  })
_sym_db.RegisterMessage(AdminState)

OperStatus = _reflection.GeneratedProtocolMessageType('OperStatus', (_message.Message,), {
  'DESCRIPTOR' : _OPERSTATUS,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.OperStatus)
  })
_sym_db.RegisterMessage(OperStatus)

ConnectStatus = _reflection.GeneratedProtocolMessageType('ConnectStatus', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTSTATUS,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.ConnectStatus)
  })
_sym_db.RegisterMessage(ConnectStatus)

OperationResp = _reflection.GeneratedProtocolMessageType('OperationResp', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONRESP,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.OperationResp)
  })
_sym_db.RegisterMessage(OperationResp)

ValueType = _reflection.GeneratedProtocolMessageType('ValueType', (_message.Message,), {
  'DESCRIPTOR' : _VALUETYPE,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.ValueType)
  })
_sym_db.RegisterMessage(ValueType)

ValueSpecifier = _reflection.GeneratedProtocolMessageType('ValueSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _VALUESPECIFIER,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.ValueSpecifier)
  })
_sym_db.RegisterMessage(ValueSpecifier)

ReturnValues = _reflection.GeneratedProtocolMessageType('ReturnValues', (_message.Message,), {
  'DESCRIPTOR' : _RETURNVALUES,
  '__module__' : 'voltha_protos.common_pb2'
  # @@protoc_insertion_point(class_scope:common.ReturnValues)
  })
_sym_db.RegisterMessage(ReturnValues)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voltha.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import meta_pb2 as voltha__protos_dot_meta__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import logical_device_pb2 as voltha__protos_dot_logical__device__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import adapter_pb2 as voltha__protos_dot_adapter__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import omci_mib_db_pb2 as voltha__protos_dot_omci__mib__db__pb2
from voltha_protos import omci_alarm_db_pb2 as voltha__protos_dot_omci__alarm__db__pb2
from voltha_protos import ext_config_pb2 as voltha__protos_dot_ext__config__pb2

from voltha_protos.meta_pb2 import *
from voltha_protos.common_pb2 import *
from voltha_protos.health_pb2 import *
from voltha_protos.logical_device_pb2 import *
from voltha_protos.device_pb2 import *
from voltha_protos.adapter_pb2 import *
from voltha_protos.openflow_13_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/voltha.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaB\014VolthaProtosZ.github.com/opencord/voltha-protos/v3/go/voltha\252\002\026Opencord.Voltha.Voltha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1avoltha_protos/voltha.proto\x12\x06voltha\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x18voltha_protos/meta.proto\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/health.proto\x1a\"voltha_protos/logical_device.proto\x1a\x1avoltha_protos/device.proto\x1a\x1bvoltha_protos/adapter.proto\x1a\x1fvoltha_protos/openflow_13.proto\x1a\x1fvoltha_protos/omci_mib_db.proto\x1a!voltha_protos/omci_alarm_db.proto\x1a\x1evoltha_protos/ext_config.proto\"\x87\x01\n\x0b\x44\x65viceGroup\x12\x11\n\x02id\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x39\n\x0flogical_devices\x18\x02 \x03(\x0b\x32\x15.voltha.LogicalDeviceB\t\xe2\xf6\xcd\x1d\x04\n\x02id\x12*\n\x07\x64\x65vices\x18\x03 \x03(\x0b\x32\x0e.voltha.DeviceB\t\xe2\xf6\xcd\x1d\x04\n\x02id\"2\n\x0c\x44\x65viceGroups\x12\"\n\x05items\x18\x01 \x03(\x0b\x32\x13.voltha.DeviceGroup\"\x9e\x01\n\x12\x45ventFilterRuleKey\"\x87\x01\n\x13\x45ventFilterRuleType\x12\x0e\n\nfilter_all\x10\x00\x12\x0c\n\x08\x63\x61tegory\x10\x01\x12\x10\n\x0csub_category\x10\x02\x12\x12\n\x0ekpi_event_type\x10\x03\x12\x15\n\x11\x63onfig_event_type\x10\x04\x12\x15\n\x11\x64\x65vice_event_type\x10\x05\"]\n\x0f\x45ventFilterRule\x12;\n\x03key\x18\x01 \x01(\x0e\x32..voltha.EventFilterRuleKey.EventFilterRuleType\x12\r\n\x05value\x18\x02 \x01(\t\"\x7f\n\x0b\x45ventFilter\x12\x11\n\x02id\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x12\n\nevent_type\x18\x04 \x01(\t\x12&\n\x05rules\x18\x05 \x03(\x0b\x32\x17.voltha.EventFilterRule\"4\n\x0c\x45ventFilters\x12$\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x13.voltha.EventFilter\"W\n\x0c\x43oreInstance\x12\x1a\n\x0binstance_id\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12+\n\x06health\x18\x02 \x01(\x0b\x32\x14.voltha.HealthStatusB\x05\xe2\xf6\xcd\x1d\x00\"4\n\rCoreInstances\x12#\n\x05items\x18\x01 \x03(\x0b\x32\x14.voltha.CoreInstance\"+\n\x0fOmciTestRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"w\n\x0cTestResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.voltha.TestResponse.TestResponseResult\".\n\x12TestResponseResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\"L\n\x08ValueSet\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x0c\x61larm_config\x18\x02 \x01(\x0b\x32\x13.config.AlarmConfigH\x00\x42\x07\n\x05value\"\xe0\x03\n\x06Voltha\x12\x16\n\x07version\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12,\n\x08\x61\x64\x61pters\x18\x02 \x03(\x0b\x32\x0f.voltha.AdapterB\t\xe2\xf6\xcd\x1d\x04\n\x02id\x12\x39\n\x0flogical_devices\x18\x03 \x03(\x0b\x32\x15.voltha.LogicalDeviceB\t\xe2\xf6\xcd\x1d\x04\n\x02id\x12*\n\x07\x64\x65vices\x18\x04 \x03(\x0b\x32\x0e.voltha.DeviceB\t\xe2\xf6\xcd\x1d\x04\n\x02id\x12\x33\n\x0c\x64\x65vice_types\x18\x05 \x03(\x0b\x32\x12.voltha.DeviceTypeB\t\xe2\xf6\xcd\x1d\x04\n\x02id\x12\x35\n\rdevice_groups\x18\x06 \x03(\x0b\x32\x13.voltha.DeviceGroupB\t\xe2\xf6\xcd\x1d\x04\n\x02id\x12\x35\n\revent_filters\x18\x07 \x03(\x0b\x32\x13.voltha.EventFilterB\t\xe2\xf6\xcd\x1d\x04\n\x02id\x12@\n\x11omci_mib_database\x18\x1c \x03(\x0b\x32\x13.omci.MibDeviceDataB\x10\xe2\xf6\xcd\x1d\x0b\n\tdevice_id\x12\x44\n\x13omci_alarm_database\x18\x1d \x03(\x0b\x32\x15.omci.AlarmDeviceDataB\x10\xe2\xf6\xcd\x1d\x0b\n\tdevice_id\"\x9d\x01\n\x10SelfTestResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.voltha.SelfTestResponse.SelfTestResult\"P\n\x0eSelfTestResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x11\n\rNOT_SUPPORTED\x10\x02\x12\x11\n\rUNKNOWN_ERROR\x10\x03\":\n\x11OfAgentSubscriber\x12\x12\n\nofagent_id\x18\x01 \x01(\t\x12\x11\n\tvoltha_id\x18\x02 \x01(\t\",\n\nMembership\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"=\n\x0c\x46lowMetadata\x12-\n\x06meters\x18\x01 \x03(\x0b\x32\x1d.openflow_13.ofp_meter_config2\xed/\n\rVolthaService\x12W\n\rGetMembership\x12\x16.google.protobuf.Empty\x1a\x12.voltha.Membership\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1/membership\x12]\n\x10UpdateMembership\x12\x12.voltha.Membership\x1a\x16.google.protobuf.Empty\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/membership:\x01*\x12\x44\n\tGetVoltha\x12\x16.google.protobuf.Empty\x1a\x0e.voltha.Voltha\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/api/v1\x12]\n\x11ListCoreInstances\x12\x16.google.protobuf.Empty\x1a\x15.voltha.CoreInstances\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/instances\x12S\n\x0fGetCoreInstance\x12\n.common.ID\x1a\x14.voltha.CoreInstance\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/instances/{id}\x12R\n\x0cListAdapters\x12\x16.google.protobuf.Empty\x1a\x10.voltha.Adapters\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/adapters\x12\x65\n\x12ListLogicalDevices\x12\x16.google.protobuf.Empty\x1a\x16.voltha.LogicalDevices\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/logical_devices\x12[\n\x10GetLogicalDevice\x12\n.common.ID\x1a\x15.voltha.LogicalDevice\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/logical_devices/{id}\x12\x66\n\x16ListLogicalDevicePorts\x12\n.common.ID\x1a\x14.voltha.LogicalPorts\"*\x82\xd3\xe4\x93\x02$\x12\"/api/v1/logical_devices/{id}/ports\x12x\n\x14GetLogicalDevicePort\x12\x15.voltha.LogicalPortId\x1a\x13.voltha.LogicalPort\"4\x82\xd3\xe4\x93\x02.\x12,/api/v1/logical_devices/{id}/ports/{port_id}\x12\x85\x01\n\x17\x45nableLogicalDevicePort\x12\x15.voltha.LogicalPortId\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"3/api/v1/logical_devices/{id}/ports/{port_id}/enable\x12\x87\x01\n\x18\x44isableLogicalDevicePort\x12\x15.voltha.LogicalPortId\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36\"4/api/v1/logical_devices/{id}/ports/{port_id}/disable\x12\x64\n\x16ListLogicalDeviceFlows\x12\n.common.ID\x1a\x12.openflow_13.Flows\"*\x82\xd3\xe4\x93\x02$\x12\"/api/v1/logical_devices/{id}/flows\x12\x83\x01\n\x1cUpdateLogicalDeviceFlowTable\x12\x1c.openflow_13.FlowTableUpdate\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'\"\"/api/v1/logical_devices/{id}/flows:\x01*\x12\x84\x01\n\x1dUpdateLogicalDeviceMeterTable\x12\x1b.openflow_13.MeterModUpdate\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\"#/api/v1/logical_devices/{id}/meters:\x01*\x12g\n\x17ListLogicalDeviceMeters\x12\n.common.ID\x1a\x13.openflow_13.Meters\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/logical_devices/{id}/meters\x12t\n\x1bListLogicalDeviceFlowGroups\x12\n.common.ID\x1a\x17.openflow_13.FlowGroups\"0\x82\xd3\xe4\x93\x02*\x12(/api/v1/logical_devices/{id}/flow_groups\x12\x93\x01\n!UpdateLogicalDeviceFlowGroupTable\x12!.openflow_13.FlowGroupTableUpdate\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/api/v1/logical_devices/{id}/flow_groups:\x01*\x12O\n\x0bListDevices\x12\x16.google.protobuf.Empty\x1a\x0f.voltha.Devices\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/devices\x12O\n\rListDeviceIds\x12\x16.google.protobuf.Empty\x1a\x0b.common.IDs\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/deviceids\x12U\n\x10ReconcileDevices\x12\x0b.common.IDs\x1a\x16.google.protobuf.Empty\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/api/v1/deviceids:\x01*\x12\x45\n\tGetDevice\x12\n.common.ID\x1a\x0e.voltha.Device\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/devices/{id}\x12J\n\x0c\x43reateDevice\x12\x0e.voltha.Device\x1a\x0e.voltha.Device\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/api/v1/devices:\x01*\x12W\n\x0c\x45nableDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/api/v1/devices/{id}/enable\x12Y\n\rDisableDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/api/v1/devices/{id}/disable\x12W\n\x0cRebootDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/api/v1/devices/{id}/reboot\x12W\n\x0c\x44\x65leteDevice\x12\n.common.ID\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/api/v1/devices/{id}/delete\x12u\n\rDownloadImage\x12\x15.voltha.ImageDownload\x1a\x15.common.OperationResp\"6\x82\xd3\xe4\x93\x02\x30\"+/api/v1/devices/{id}/image_downloads/{name}:\x01*\x12\x82\x01\n\x16GetImageDownloadStatus\x12\x15.voltha.ImageDownload\x1a\x15.voltha.ImageDownload\":\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/devices/{id}/image_downloads/{name}/status\x12u\n\x10GetImageDownload\x12\x15.voltha.ImageDownload\x1a\x15.voltha.ImageDownload\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/devices/{id}/image_downloads/{name}\x12\x66\n\x12ListImageDownloads\x12\n.common.ID\x1a\x16.voltha.ImageDownloads\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/devices/{id}/image_downloads\x12x\n\x13\x43\x61ncelImageDownload\x12\x15.voltha.ImageDownload\x1a\x15.common.OperationResp\"3\x82\xd3\xe4\x93\x02-*+/api/v1/devices/{id}/image_downloads/{name}\x12\x88\x01\n\x13\x41\x63tivateImageUpdate\x12\x15.voltha.ImageDownload\x1a\x15.common.OperationResp\"C\x82\xd3\xe4\x93\x02=\"8/api/v1/devices/{id}/image_downloads/{name}/image_update:\x01*\x12\x86\x01\n\x11RevertImageUpdate\x12\x15.voltha.ImageDownload\x1a\x15.common.OperationResp\"C\x82\xd3\xe4\x93\x02=\"8/api/v1/devices/{id}/image_downloads/{name}/image_revert:\x01*\x12P\n\x0fListDevicePorts\x12\n.common.ID\x1a\r.voltha.Ports\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/devices/{id}/ports\x12]\n\x13ListDevicePmConfigs\x12\n.common.ID\x1a\x11.voltha.PmConfigs\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/devices/{id}/pm_configs\x12n\n\x15UpdateDevicePmConfigs\x12\x11.voltha.PmConfigs\x1a\x16.google.protobuf.Empty\"*\x82\xd3\xe4\x93\x02$\"\x1f/api/v1/devices/{id}/pm_configs:\x01*\x12U\n\x0fListDeviceFlows\x12\n.common.ID\x1a\x12.openflow_13.Flows\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/devices/{id}/flows\x12\x65\n\x14ListDeviceFlowGroups\x12\n.common.ID\x1a\x17.openflow_13.FlowGroups\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/devices/{id}/flow_groups\x12\\\n\x0fListDeviceTypes\x12\x16.google.protobuf.Empty\x1a\x13.voltha.DeviceTypes\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/device_types\x12R\n\rGetDeviceType\x12\n.common.ID\x1a\x12.voltha.DeviceType\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/device_types/{id}\x12_\n\x10ListDeviceGroups\x12\x16.google.protobuf.Empty\x1a\x14.voltha.DeviceGroups\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/device_groups\x12\x46\n\x10StreamPacketsOut\x12\x16.openflow_13.PacketOut\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12\x45\n\x10ReceivePacketsIn\x12\x16.google.protobuf.Empty\x1a\x15.openflow_13.PacketIn\"\x00\x30\x01\x12K\n\x13ReceiveChangeEvents\x12\x16.google.protobuf.Empty\x1a\x18.openflow_13.ChangeEvent\"\x00\x30\x01\x12U\n\x0eGetDeviceGroup\x12\n.common.ID\x1a\x13.voltha.DeviceGroup\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/device_groups/{id}\x12_\n\x11\x43reateEventFilter\x12\x13.voltha.EventFilter\x1a\x13.voltha.EventFilter\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/event_filters:\x01*\x12V\n\x0eGetEventFilter\x12\n.common.ID\x1a\x14.voltha.EventFilters\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/event_filters/{id}\x12\x64\n\x11UpdateEventFilter\x12\x13.voltha.EventFilter\x1a\x13.voltha.EventFilter\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/event_filters/{id}:\x01*\x12\x64\n\x11\x44\x65leteEventFilter\x12\x13.voltha.EventFilter\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/api/v1/event_filters/{id}\x12_\n\x10ListEventFilters\x12\x16.google.protobuf.Empty\x1a\x14.voltha.EventFilters\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/event_filters\x12L\n\tGetImages\x12\n.common.ID\x1a\x0e.voltha.Images\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/devices/{id}/images\x12X\n\x08SelfTest\x12\n.common.ID\x1a\x18.voltha.SelfTestResponse\"&\x82\xd3\xe4\x93\x02 \"\x1e/api/v1/devices/{id}/self_test\x12V\n\x10GetMibDeviceData\x12\n.common.ID\x1a\x13.omci.MibDeviceData\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/openomci/{id}/mib\x12\\\n\x12GetAlarmDeviceData\x12\n.common.ID\x1a\x15.omci.AlarmDeviceData\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/openomci/{id}/alarm\x12s\n\rSimulateAlarm\x12\x1c.voltha.SimulateAlarmRequest\x1a\x15.common.OperationResp\"-\x82\xd3\xe4\x93\x02\'\"\"/api/v1/devices/{id}/simulate_larm:\x01*\x12\x43\n\tSubscribe\x12\x19.voltha.OfAgentSubscriber\x1a\x19.voltha.OfAgentSubscriber\"\x00\x12M\n\nEnablePort\x12\x0c.voltha.Port\x1a\x16.google.protobuf.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/EnablePort:\x01*\x12O\n\x0b\x44isablePort\x12\x0c.voltha.Port\x1a\x16.google.protobuf.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/DisablePort:\x01*\x12X\n\x0bGetExtValue\x12\x16.common.ValueSpecifier\x1a\x14.common.ReturnValues\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/GetExtValue\x12T\n\x0bSetExtValue\x12\x10.voltha.ValueSet\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/SetExtValue\x12h\n\x13StartOmciTestAction\x12\x17.voltha.OmciTestRequest\x1a\x14.voltha.TestResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/start_omci_test:\x01*Bl\n\x13org.opencord.volthaB\x0cVolthaProtosZ.github.com/opencord/voltha-protos/v3/go/voltha\xaa\x02\x16Opencord.Voltha.VolthaP\x02P\x03P\x04P\x05P\x06P\x07P\x08\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_meta__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_health__pb2.DESCRIPTOR,voltha__protos_dot_logical__device__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,voltha__protos_dot_adapter__pb2.DESCRIPTOR,voltha__protos_dot_openflow__13__pb2.DESCRIPTOR,voltha__protos_dot_omci__mib__db__pb2.DESCRIPTOR,voltha__protos_dot_omci__alarm__db__pb2.DESCRIPTOR,voltha__protos_dot_ext__config__pb2.DESCRIPTOR,],
  public_dependencies=[voltha__protos_dot_meta__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_health__pb2.DESCRIPTOR,voltha__protos_dot_logical__device__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,voltha__protos_dot_adapter__pb2.DESCRIPTOR,voltha__protos_dot_openflow__13__pb2.DESCRIPTOR,])



_EVENTFILTERRULEKEY_EVENTFILTERRULETYPE = _descriptor.EnumDescriptor(
  name='EventFilterRuleType',
  full_name='voltha.EventFilterRuleKey.EventFilterRuleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='filter_all', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='category', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='sub_category', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='kpi_event_type', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='config_event_type', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='device_event_type', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=619,
  serialized_end=754,
)
_sym_db.RegisterEnumDescriptor(_EVENTFILTERRULEKEY_EVENTFILTERRULETYPE)

_TESTRESPONSE_TESTRESPONSERESULT = _descriptor.EnumDescriptor(
  name='TestResponseResult',
  full_name='voltha.TestResponse.TestResponseResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1295,
  serialized_end=1341,
)
_sym_db.RegisterEnumDescriptor(_TESTRESPONSE_TESTRESPONSERESULT)

_SELFTESTRESPONSE_SELFTESTRESULT = _descriptor.EnumDescriptor(
  name='SelfTestResult',
  full_name='voltha.SelfTestResponse.SelfTestResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1982,
  serialized_end=2062,
)
_sym_db.RegisterEnumDescriptor(_SELFTESTRESPONSE_SELFTESTRESULT)


_DEVICEGROUP = _descriptor.Descriptor(
  name='DeviceGroup',
  full_name='voltha.DeviceGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.DeviceGroup.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logical_devices', full_name='voltha.DeviceGroup.logical_devices', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devices', full_name='voltha.DeviceGroup.devices', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=541,
)


_DEVICEGROUPS = _descriptor.Descriptor(
  name='DeviceGroups',
  full_name='voltha.DeviceGroups',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.DeviceGroups.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=593,
)


_EVENTFILTERRULEKEY = _descriptor.Descriptor(
  name='EventFilterRuleKey',
  full_name='voltha.EventFilterRuleKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTFILTERRULEKEY_EVENTFILTERRULETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=754,
)


_EVENTFILTERRULE = _descriptor.Descriptor(
  name='EventFilterRule',
  full_name='voltha.EventFilterRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.EventFilterRule.key', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.EventFilterRule.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=849,
)


_EVENTFILTER = _descriptor.Descriptor(
  name='EventFilter',
  full_name='voltha.EventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.EventFilter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='voltha.EventFilter.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.EventFilter.device_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='voltha.EventFilter.event_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='voltha.EventFilter.rules', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=978,
)


_EVENTFILTERS = _descriptor.Descriptor(
  name='EventFilters',
  full_name='voltha.EventFilters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='voltha.EventFilters.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=980,
  serialized_end=1032,
)


_COREINSTANCE = _descriptor.Descriptor(
  name='CoreInstance',
  full_name='voltha.CoreInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='voltha.CoreInstance.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='voltha.CoreInstance.health', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1121,
)


_COREINSTANCES = _descriptor.Descriptor(
  name='CoreInstances',
  full_name='voltha.CoreInstances',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.CoreInstances.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1175,
)


_OMCITESTREQUEST = _descriptor.Descriptor(
  name='OmciTestRequest',
  full_name='voltha.OmciTestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.OmciTestRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='voltha.OmciTestRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1177,
  serialized_end=1220,
)


_TESTRESPONSE = _descriptor.Descriptor(
  name='TestResponse',
  full_name='voltha.TestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='voltha.TestResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TESTRESPONSE_TESTRESPONSERESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1341,
)


_VALUESET = _descriptor.Descriptor(
  name='ValueSet',
  full_name='voltha.ValueSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.ValueSet.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alarm_config', full_name='voltha.ValueSet.alarm_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='voltha.ValueSet.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1343,
  serialized_end=1419,
)


_VOLTHA = _descriptor.Descriptor(
  name='Voltha',
  full_name='voltha.Voltha',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='voltha.Voltha.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adapters', full_name='voltha.Voltha.adapters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logical_devices', full_name='voltha.Voltha.logical_devices', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devices', full_name='voltha.Voltha.devices', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_types', full_name='voltha.Voltha.device_types', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_groups', full_name='voltha.Voltha.device_groups', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_filters', full_name='voltha.Voltha.event_filters', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omci_mib_database', full_name='voltha.Voltha.omci_mib_database', index=7,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\013\n\tdevice_id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omci_alarm_database', full_name='voltha.Voltha.omci_alarm_database', index=8,
      number=29, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\013\n\tdevice_id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1422,
  serialized_end=1902,
)


_SELFTESTRESPONSE = _descriptor.Descriptor(
  name='SelfTestResponse',
  full_name='voltha.SelfTestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='voltha.SelfTestResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SELFTESTRESPONSE_SELFTESTRESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1905,
  serialized_end=2062,
)


_OFAGENTSUBSCRIBER = _descriptor.Descriptor(
  name='OfAgentSubscriber',
  full_name='voltha.OfAgentSubscriber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ofagent_id', full_name='voltha.OfAgentSubscriber.ofagent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voltha_id', full_name='voltha.OfAgentSubscriber.voltha_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2064,
  serialized_end=2122,
)


_MEMBERSHIP = _descriptor.Descriptor(
  name='Membership',
  full_name='voltha.Membership',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_name', full_name='voltha.Membership.group_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.Membership.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2124,
  serialized_end=2168,
)


_FLOWMETADATA = _descriptor.Descriptor(
  name='FlowMetadata',
  full_name='voltha.FlowMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meters', full_name='voltha.FlowMetadata.meters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2170,
  serialized_end=2231,
)

_DEVICEGROUP.fields_by_name['logical_devices'].message_type = voltha__protos_dot_logical__device__pb2._LOGICALDEVICE
_DEVICEGROUP.fields_by_name['devices'].message_type = voltha__protos_dot_device__pb2._DEVICE
_DEVICEGROUPS.fields_by_name['items'].message_type = _DEVICEGROUP
_EVENTFILTERRULEKEY_EVENTFILTERRULETYPE.containing_type = _EVENTFILTERRULEKEY
_EVENTFILTERRULE.fields_by_name['key'].enum_type = _EVENTFILTERRULEKEY_EVENTFILTERRULETYPE
_EVENTFILTER.fields_by_name['rules'].message_type = _EVENTFILTERRULE
_EVENTFILTERS.fields_by_name['filters'].message_type = _EVENTFILTER
_COREINSTANCE.fields_by_name['health'].message_type = voltha__protos_dot_health__pb2._HEALTHSTATUS
_COREINSTANCES.fields_by_name['items'].message_type = _COREINSTANCE
_TESTRESPONSE.fields_by_name['result'].enum_type = _TESTRESPONSE_TESTRESPONSERESULT
_TESTRESPONSE_TESTRESPONSERESULT.containing_type = _TESTRESPONSE
_VALUESET.fields_by_name['alarm_config'].message_type = voltha__protos_dot_ext__config__pb2._ALARMCONFIG
_VALUESET.oneofs_by_name['value'].fields.append(
  _VALUESET.fields_by_name['alarm_config'])
_VALUESET.fields_by_name['alarm_config'].containing_oneof = _VALUESET.oneofs_by_name['value']
_VOLTHA.fields_by_name['adapters'].message_type = voltha__protos_dot_adapter__pb2._ADAPTER
_VOLTHA.fields_by_name['logical_devices'].message_type = voltha__protos_dot_logical__device__pb2._LOGICALDEVICE
_VOLTHA.fields_by_name['devices'].message_type = voltha__protos_dot_device__pb2._DEVICE
_VOLTHA.fields_by_name['device_types'].message_type = voltha__protos_dot_device__pb2._DEVICETYPE
_VOLTHA.fields_by_name['device_groups'].message_type = _DEVICEGROUP
_VOLTHA.fields_by_name['event_filters'].message_type = _EVENTFILTER
_VOLTHA.fields_by_name['omci_mib_database'].message_type = voltha__protos_dot_omci__mib__db__pb2._MIBDEVICEDATA
_VOLTHA.fields_by_name['omci_alarm_database'].message_type = voltha__protos_dot_omci__alarm__db__pb2._ALARMDEVICEDATA
_SELFTESTRESPONSE.fields_by_name['result'].enum_type = _SELFTESTRESPONSE_SELFTESTRESULT
_SELFTESTRESPONSE_SELFTESTRESULT.containing_type = _SELFTESTRESPONSE
_FLOWMETADATA.fields_by_name['meters'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_METER_CONFIG
DESCRIPTOR.message_types_by_name['DeviceGroup'] = _DEVICEGROUP
DESCRIPTOR.message_types_by_name['DeviceGroups'] = _DEVICEGROUPS
DESCRIPTOR.message_types_by_name['EventFilterRuleKey'] = _EVENTFILTERRULEKEY
DESCRIPTOR.message_types_by_name['EventFilterRule'] = _EVENTFILTERRULE
DESCRIPTOR.message_types_by_name['EventFilter'] = _EVENTFILTER
DESCRIPTOR.message_types_by_name['EventFilters'] = _EVENTFILTERS
DESCRIPTOR.message_types_by_name['CoreInstance'] = _COREINSTANCE
DESCRIPTOR.message_types_by_name['CoreInstances'] = _COREINSTANCES
DESCRIPTOR.message_types_by_name['OmciTestRequest'] = _OMCITESTREQUEST
DESCRIPTOR.message_types_by_name['TestResponse'] = _TESTRESPONSE
DESCRIPTOR.message_types_by_name['ValueSet'] = _VALUESET
DESCRIPTOR.message_types_by_name['Voltha'] = _VOLTHA
DESCRIPTOR.message_types_by_name['SelfTestResponse'] = _SELFTESTRESPONSE
DESCRIPTOR.message_types_by_name['OfAgentSubscriber'] = _OFAGENTSUBSCRIBER
DESCRIPTOR.message_types_by_name['Membership'] = _MEMBERSHIP
DESCRIPTOR.message_types_by_name['FlowMetadata'] = _FLOWMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeviceGroup = _reflection.GeneratedProtocolMessageType('DeviceGroup', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGROUP,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceGroup)
  })
_sym_db.RegisterMessage(DeviceGroup)

DeviceGroups = _reflection.GeneratedProtocolMessageType('DeviceGroups', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGROUPS,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceGroups)
  })
_sym_db.RegisterMessage(DeviceGroups)

EventFilterRuleKey = _reflection.GeneratedProtocolMessageType('EventFilterRuleKey', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTERRULEKEY,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.EventFilterRuleKey)
  })
_sym_db.RegisterMessage(EventFilterRuleKey)

EventFilterRule = _reflection.GeneratedProtocolMessageType('EventFilterRule', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTERRULE,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.EventFilterRule)
  })
_sym_db.RegisterMessage(EventFilterRule)

EventFilter = _reflection.GeneratedProtocolMessageType('EventFilter', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTER,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.EventFilter)
  })
_sym_db.RegisterMessage(EventFilter)

EventFilters = _reflection.GeneratedProtocolMessageType('EventFilters', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTERS,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.EventFilters)
  })
_sym_db.RegisterMessage(EventFilters)

CoreInstance = _reflection.GeneratedProtocolMessageType('CoreInstance', (_message.Message,), {
  'DESCRIPTOR' : _COREINSTANCE,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.CoreInstance)
  })
_sym_db.RegisterMessage(CoreInstance)

CoreInstances = _reflection.GeneratedProtocolMessageType('CoreInstances', (_message.Message,), {
  'DESCRIPTOR' : _COREINSTANCES,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.CoreInstances)
  })
_sym_db.RegisterMessage(CoreInstances)

OmciTestRequest = _reflection.GeneratedProtocolMessageType('OmciTestRequest', (_message.Message,), {
  'DESCRIPTOR' : _OMCITESTREQUEST,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.OmciTestRequest)
  })
_sym_db.RegisterMessage(OmciTestRequest)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESPONSE,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.TestResponse)
  })
_sym_db.RegisterMessage(TestResponse)

ValueSet = _reflection.GeneratedProtocolMessageType('ValueSet', (_message.Message,), {
  'DESCRIPTOR' : _VALUESET,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ValueSet)
  })
_sym_db.RegisterMessage(ValueSet)

Voltha = _reflection.GeneratedProtocolMessageType('Voltha', (_message.Message,), {
  'DESCRIPTOR' : _VOLTHA,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Voltha)
  })
_sym_db.RegisterMessage(Voltha)

SelfTestResponse = _reflection.GeneratedProtocolMessageType('SelfTestResponse', (_message.Message,), {
  'DESCRIPTOR' : _SELFTESTRESPONSE,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.SelfTestResponse)
  })
_sym_db.RegisterMessage(SelfTestResponse)

OfAgentSubscriber = _reflection.GeneratedProtocolMessageType('OfAgentSubscriber', (_message.Message,), {
  'DESCRIPTOR' : _OFAGENTSUBSCRIBER,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.OfAgentSubscriber)
  })
_sym_db.RegisterMessage(OfAgentSubscriber)

Membership = _reflection.GeneratedProtocolMessageType('Membership', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERSHIP,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Membership)
  })
_sym_db.RegisterMessage(Membership)

FlowMetadata = _reflection.GeneratedProtocolMessageType('FlowMetadata', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMETADATA,
  '__module__' : 'voltha_protos.voltha_pb2'
  # @@protoc_insertion_point(class_scope:voltha.FlowMetadata)
  })
_sym_db.RegisterMessage(FlowMetadata)


DESCRIPTOR._options = None
_DEVICEGROUP.fields_by_name['id']._options = None
_DEVICEGROUP.fields_by_name['logical_devices']._options = None
_DEVICEGROUP.fields_by_name['devices']._options = None
_EVENTFILTER.fields_by_name['id']._options = None
_COREINSTANCE.fields_by_name['instance_id']._options = None
_COREINSTANCE.fields_by_name['health']._options = None
_VOLTHA.fields_by_name['version']._options = None
_VOLTHA.fields_by_name['adapters']._options = None
_VOLTHA.fields_by_name['logical_devices']._options = None
_VOLTHA.fields_by_name['devices']._options = None
_VOLTHA.fields_by_name['device_types']._options = None
_VOLTHA.fields_by_name['device_groups']._options = None
_VOLTHA.fields_by_name['event_filters']._options = None
_VOLTHA.fields_by_name['omci_mib_database']._options = None
_VOLTHA.fields_by_name['omci_alarm_database']._options = None

_VOLTHASERVICE = _descriptor.ServiceDescriptor(
  name='VolthaService',
  full_name='voltha.VolthaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2234,
  serialized_end=8359,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMembership',
    full_name='voltha.VolthaService.GetMembership',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_MEMBERSHIP,
    serialized_options=b'\202\323\344\223\002\024\022\022/api/v1/membership',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMembership',
    full_name='voltha.VolthaService.UpdateMembership',
    index=1,
    containing_service=None,
    input_type=_MEMBERSHIP,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\027\"\022/api/v1/membership:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVoltha',
    full_name='voltha.VolthaService.GetVoltha',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_VOLTHA,
    serialized_options=b'\202\323\344\223\002\t\022\007/api/v1',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCoreInstances',
    full_name='voltha.VolthaService.ListCoreInstances',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_COREINSTANCES,
    serialized_options=b'\202\323\344\223\002\023\022\021/api/v1/instances',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCoreInstance',
    full_name='voltha.VolthaService.GetCoreInstance',
    index=4,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=_COREINSTANCE,
    serialized_options=b'\202\323\344\223\002\030\022\026/api/v1/instances/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAdapters',
    full_name='voltha.VolthaService.ListAdapters',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_adapter__pb2._ADAPTERS,
    serialized_options=b'\202\323\344\223\002\022\022\020/api/v1/adapters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogicalDevices',
    full_name='voltha.VolthaService.ListLogicalDevices',
    index=6,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_logical__device__pb2._LOGICALDEVICES,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1/logical_devices',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogicalDevice',
    full_name='voltha.VolthaService.GetLogicalDevice',
    index=7,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_logical__device__pb2._LOGICALDEVICE,
    serialized_options=b'\202\323\344\223\002\036\022\034/api/v1/logical_devices/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogicalDevicePorts',
    full_name='voltha.VolthaService.ListLogicalDevicePorts',
    index=8,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_logical__device__pb2._LOGICALPORTS,
    serialized_options=b'\202\323\344\223\002$\022\"/api/v1/logical_devices/{id}/ports',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogicalDevicePort',
    full_name='voltha.VolthaService.GetLogicalDevicePort',
    index=9,
    containing_service=None,
    input_type=voltha__protos_dot_logical__device__pb2._LOGICALPORTID,
    output_type=voltha__protos_dot_logical__device__pb2._LOGICALPORT,
    serialized_options=b'\202\323\344\223\002.\022,/api/v1/logical_devices/{id}/ports/{port_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableLogicalDevicePort',
    full_name='voltha.VolthaService.EnableLogicalDevicePort',
    index=10,
    containing_service=None,
    input_type=voltha__protos_dot_logical__device__pb2._LOGICALPORTID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\0025\"3/api/v1/logical_devices/{id}/ports/{port_id}/enable',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableLogicalDevicePort',
    full_name='voltha.VolthaService.DisableLogicalDevicePort',
    index=11,
    containing_service=None,
    input_type=voltha__protos_dot_logical__device__pb2._LOGICALPORTID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\0026\"4/api/v1/logical_devices/{id}/ports/{port_id}/disable',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogicalDeviceFlows',
    full_name='voltha.VolthaService.ListLogicalDeviceFlows',
    index=12,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_openflow__13__pb2._FLOWS,
    serialized_options=b'\202\323\344\223\002$\022\"/api/v1/logical_devices/{id}/flows',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLogicalDeviceFlowTable',
    full_name='voltha.VolthaService.UpdateLogicalDeviceFlowTable',
    index=13,
    containing_service=None,
    input_type=voltha__protos_dot_openflow__13__pb2._FLOWTABLEUPDATE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\'\"\"/api/v1/logical_devices/{id}/flows:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLogicalDeviceMeterTable',
    full_name='voltha.VolthaService.UpdateLogicalDeviceMeterTable',
    index=14,
    containing_service=None,
    input_type=voltha__protos_dot_openflow__13__pb2._METERMODUPDATE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002(\"#/api/v1/logical_devices/{id}/meters:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogicalDeviceMeters',
    full_name='voltha.VolthaService.ListLogicalDeviceMeters',
    index=15,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_openflow__13__pb2._METERS,
    serialized_options=b'\202\323\344\223\002%\022#/api/v1/logical_devices/{id}/meters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogicalDeviceFlowGroups',
    full_name='voltha.VolthaService.ListLogicalDeviceFlowGroups',
    index=16,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_openflow__13__pb2._FLOWGROUPS,
    serialized_options=b'\202\323\344\223\002*\022(/api/v1/logical_devices/{id}/flow_groups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLogicalDeviceFlowGroupTable',
    full_name='voltha.VolthaService.UpdateLogicalDeviceFlowGroupTable',
    index=17,
    containing_service=None,
    input_type=voltha__protos_dot_openflow__13__pb2._FLOWGROUPTABLEUPDATE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002-\"(/api/v1/logical_devices/{id}/flow_groups:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDevices',
    full_name='voltha.VolthaService.ListDevices',
    index=18,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_device__pb2._DEVICES,
    serialized_options=b'\202\323\344\223\002\021\022\017/api/v1/devices',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDeviceIds',
    full_name='voltha.VolthaService.ListDeviceIds',
    index=19,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_common__pb2._IDS,
    serialized_options=b'\202\323\344\223\002\023\022\021/api/v1/deviceids',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReconcileDevices',
    full_name='voltha.VolthaService.ReconcileDevices',
    index=20,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._IDS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\026\"\021/api/v1/deviceids:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevice',
    full_name='voltha.VolthaService.GetDevice',
    index=21,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=b'\202\323\344\223\002\026\022\024/api/v1/devices/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDevice',
    full_name='voltha.VolthaService.CreateDevice',
    index=22,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=b'\202\323\344\223\002\024\"\017/api/v1/devices:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableDevice',
    full_name='voltha.VolthaService.EnableDevice',
    index=23,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\035\"\033/api/v1/devices/{id}/enable',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableDevice',
    full_name='voltha.VolthaService.DisableDevice',
    index=24,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\036\"\034/api/v1/devices/{id}/disable',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RebootDevice',
    full_name='voltha.VolthaService.RebootDevice',
    index=25,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\035\"\033/api/v1/devices/{id}/reboot',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDevice',
    full_name='voltha.VolthaService.DeleteDevice',
    index=26,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\035*\033/api/v1/devices/{id}/delete',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadImage',
    full_name='voltha.VolthaService.DownloadImage',
    index=27,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    output_type=voltha__protos_dot_common__pb2._OPERATIONRESP,
    serialized_options=b'\202\323\344\223\0020\"+/api/v1/devices/{id}/image_downloads/{name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageDownloadStatus',
    full_name='voltha.VolthaService.GetImageDownloadStatus',
    index=28,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\202\323\344\223\0024\0222/api/v1/devices/{id}/image_downloads/{name}/status',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageDownload',
    full_name='voltha.VolthaService.GetImageDownload',
    index=29,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\202\323\344\223\002-\022+/api/v1/devices/{id}/image_downloads/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListImageDownloads',
    full_name='voltha.VolthaService.ListImageDownloads',
    index=30,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOADS,
    serialized_options=b'\202\323\344\223\002&\022$/api/v1/devices/{id}/image_downloads',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelImageDownload',
    full_name='voltha.VolthaService.CancelImageDownload',
    index=31,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    output_type=voltha__protos_dot_common__pb2._OPERATIONRESP,
    serialized_options=b'\202\323\344\223\002-*+/api/v1/devices/{id}/image_downloads/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateImageUpdate',
    full_name='voltha.VolthaService.ActivateImageUpdate',
    index=32,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    output_type=voltha__protos_dot_common__pb2._OPERATIONRESP,
    serialized_options=b'\202\323\344\223\002=\"8/api/v1/devices/{id}/image_downloads/{name}/image_update:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevertImageUpdate',
    full_name='voltha.VolthaService.RevertImageUpdate',
    index=33,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    output_type=voltha__protos_dot_common__pb2._OPERATIONRESP,
    serialized_options=b'\202\323\344\223\002=\"8/api/v1/devices/{id}/image_downloads/{name}/image_revert:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDevicePorts',
    full_name='voltha.VolthaService.ListDevicePorts',
    index=34,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._PORTS,
    serialized_options=b'\202\323\344\223\002\034\022\032/api/v1/devices/{id}/ports',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDevicePmConfigs',
    full_name='voltha.VolthaService.ListDevicePmConfigs',
    index=35,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._PMCONFIGS,
    serialized_options=b'\202\323\344\223\002!\022\037/api/v1/devices/{id}/pm_configs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDevicePmConfigs',
    full_name='voltha.VolthaService.UpdateDevicePmConfigs',
    index=36,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PMCONFIGS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002$\"\037/api/v1/devices/{id}/pm_configs:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDeviceFlows',
    full_name='voltha.VolthaService.ListDeviceFlows',
    index=37,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_openflow__13__pb2._FLOWS,
    serialized_options=b'\202\323\344\223\002\034\022\032/api/v1/devices/{id}/flows',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDeviceFlowGroups',
    full_name='voltha.VolthaService.ListDeviceFlowGroups',
    index=38,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_openflow__13__pb2._FLOWGROUPS,
    serialized_options=b'\202\323\344\223\002\"\022 /api/v1/devices/{id}/flow_groups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDeviceTypes',
    full_name='voltha.VolthaService.ListDeviceTypes',
    index=39,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_device__pb2._DEVICETYPES,
    serialized_options=b'\202\323\344\223\002\026\022\024/api/v1/device_types',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDeviceType',
    full_name='voltha.VolthaService.GetDeviceType',
    index=40,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._DEVICETYPE,
    serialized_options=b'\202\323\344\223\002\033\022\031/api/v1/device_types/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDeviceGroups',
    full_name='voltha.VolthaService.ListDeviceGroups',
    index=41,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_DEVICEGROUPS,
    serialized_options=b'\202\323\344\223\002\027\022\025/api/v1/device_groups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamPacketsOut',
    full_name='voltha.VolthaService.StreamPacketsOut',
    index=42,
    containing_service=None,
    input_type=voltha__protos_dot_openflow__13__pb2._PACKETOUT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReceivePacketsIn',
    full_name='voltha.VolthaService.ReceivePacketsIn',
    index=43,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_openflow__13__pb2._PACKETIN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReceiveChangeEvents',
    full_name='voltha.VolthaService.ReceiveChangeEvents',
    index=44,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_openflow__13__pb2._CHANGEEVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDeviceGroup',
    full_name='voltha.VolthaService.GetDeviceGroup',
    index=45,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=_DEVICEGROUP,
    serialized_options=b'\202\323\344\223\002\034\022\032/api/v1/device_groups/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateEventFilter',
    full_name='voltha.VolthaService.CreateEventFilter',
    index=46,
    containing_service=None,
    input_type=_EVENTFILTER,
    output_type=_EVENTFILTER,
    serialized_options=b'\202\323\344\223\002\032\"\025/api/v1/event_filters:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEventFilter',
    full_name='voltha.VolthaService.GetEventFilter',
    index=47,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=_EVENTFILTERS,
    serialized_options=b'\202\323\344\223\002\034\022\032/api/v1/event_filters/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEventFilter',
    full_name='voltha.VolthaService.UpdateEventFilter',
    index=48,
    containing_service=None,
    input_type=_EVENTFILTER,
    output_type=_EVENTFILTER,
    serialized_options=b'\202\323\344\223\002\037\032\032/api/v1/event_filters/{id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteEventFilter',
    full_name='voltha.VolthaService.DeleteEventFilter',
    index=49,
    containing_service=None,
    input_type=_EVENTFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\034*\032/api/v1/event_filters/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEventFilters',
    full_name='voltha.VolthaService.ListEventFilters',
    index=50,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_EVENTFILTERS,
    serialized_options=b'\202\323\344\223\002\027\022\025/api/v1/event_filters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImages',
    full_name='voltha.VolthaService.GetImages',
    index=51,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._IMAGES,
    serialized_options=b'\202\323\344\223\002\035\022\033/api/v1/devices/{id}/images',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SelfTest',
    full_name='voltha.VolthaService.SelfTest',
    index=52,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=_SELFTESTRESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\036/api/v1/devices/{id}/self_test',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMibDeviceData',
    full_name='voltha.VolthaService.GetMibDeviceData',
    index=53,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_omci__mib__db__pb2._MIBDEVICEDATA,
    serialized_options=b'\202\323\344\223\002\033\022\031/api/v1/openomci/{id}/mib',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAlarmDeviceData',
    full_name='voltha.VolthaService.GetAlarmDeviceData',
    index=54,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_omci__alarm__db__pb2._ALARMDEVICEDATA,
    serialized_options=b'\202\323\344\223\002\035\022\033/api/v1/openomci/{id}/alarm',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SimulateAlarm',
    full_name='voltha.VolthaService.SimulateAlarm',
    index=55,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._SIMULATEALARMREQUEST,
    output_type=voltha__protos_dot_common__pb2._OPERATIONRESP,
    serialized_options=b'\202\323\344\223\002\'\"\"/api/v1/devices/{id}/simulate_larm:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='voltha.VolthaService.Subscribe',
    index=56,
    containing_service=None,
    input_type=_OFAGENTSUBSCRIBER,
    output_type=_OFAGENTSUBSCRIBER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnablePort',
    full_name='voltha.VolthaService.EnablePort',
    index=57,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\023\"\016/v1/EnablePort:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisablePort',
    full_name='voltha.VolthaService.DisablePort',
    index=58,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/DisablePort:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtValue',
    full_name='voltha.VolthaService.GetExtValue',
    index=59,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._VALUESPECIFIER,
    output_type=voltha__protos_dot_common__pb2._RETURNVALUES,
    serialized_options=b'\202\323\344\223\002\025\022\023/api/v1/GetExtValue',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExtValue',
    full_name='voltha.VolthaService.SetExtValue',
    index=60,
    containing_service=None,
    input_type=_VALUESET,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\025\022\023/api/v1/SetExtValue',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartOmciTestAction',
    full_name='voltha.VolthaService.StartOmciTestAction',
    index=61,
    containing_service=None,
    input_type=_OMCITESTREQUEST,
    output_type=_TESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/api/v1/start_omci_test:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VOLTHASERVICE)

DESCRIPTOR.services_by_name['VolthaService'] = _VOLTHASERVICE

# @@protoc_insertion_point(module_scope)
